#!/usr/local/bin/ruby
# $Id: test_StyleSheet.rb,v 1.2 2004/10/13 15:21:49 toki Exp $

require 'rubyunit'
require 'wpm'

module TestRucy
  class TestStyleSheet < RUNIT::TestCase
    def setup
      loader = WPM::Loader.new('../control/StyleSheet/StyleSheet.rb')
      @StyleSheet = loader.const_get('StyleSheet').new(self, { :control => self })
      assert((@StyleSheet.is_a? WPM::PageContext))
      @StyleSheet.init_context
    end

    def test_load
      # nothing to do.
    end
  end
end
